Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.User) predicate.User
- func CreateTime(v time.Time) predicate.User
- func CreateTimeEQ(v time.Time) predicate.User
- func CreateTimeGT(v time.Time) predicate.User
- func CreateTimeGTE(v time.Time) predicate.User
- func CreateTimeIn(vs ...time.Time) predicate.User
- func CreateTimeLT(v time.Time) predicate.User
- func CreateTimeLTE(v time.Time) predicate.User
- func CreateTimeNEQ(v time.Time) predicate.User
- func CreateTimeNotIn(vs ...time.Time) predicate.User
- func Email(v string) predicate.User
- func EmailContains(v string) predicate.User
- func EmailContainsFold(v string) predicate.User
- func EmailEQ(v string) predicate.User
- func EmailEqualFold(v string) predicate.User
- func EmailGT(v string) predicate.User
- func EmailGTE(v string) predicate.User
- func EmailHasPrefix(v string) predicate.User
- func EmailHasSuffix(v string) predicate.User
- func EmailIn(vs ...string) predicate.User
- func EmailLT(v string) predicate.User
- func EmailLTE(v string) predicate.User
- func EmailNEQ(v string) predicate.User
- func EmailNotIn(vs ...string) predicate.User
- func HasAccessTokens() predicate.User
- func HasAccessTokensWith(preds ...predicate.AccessToken) predicate.User
- func HasLikeVideos() predicate.User
- func HasLikeVideosWith(preds ...predicate.LikeVideo) predicate.User
- func HasRefreshTokens() predicate.User
- func HasRefreshTokensWith(preds ...predicate.RefreshToken) predicate.User
- func ID(id uuid.UUID) predicate.User
- func IDEQ(id uuid.UUID) predicate.User
- func IDGT(id uuid.UUID) predicate.User
- func IDGTE(id uuid.UUID) predicate.User
- func IDIn(ids ...uuid.UUID) predicate.User
- func IDLT(id uuid.UUID) predicate.User
- func IDLTE(id uuid.UUID) predicate.User
- func IDNEQ(id uuid.UUID) predicate.User
- func IDNotIn(ids ...uuid.UUID) predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func Password(v string) predicate.User
- func PasswordContains(v string) predicate.User
- func PasswordContainsFold(v string) predicate.User
- func PasswordEQ(v string) predicate.User
- func PasswordEqualFold(v string) predicate.User
- func PasswordGT(v string) predicate.User
- func PasswordGTE(v string) predicate.User
- func PasswordHasPrefix(v string) predicate.User
- func PasswordHasSuffix(v string) predicate.User
- func PasswordIn(vs ...string) predicate.User
- func PasswordLT(v string) predicate.User
- func PasswordLTE(v string) predicate.User
- func PasswordNEQ(v string) predicate.User
- func PasswordNotIn(vs ...string) predicate.User
- func UpdateTime(v time.Time) predicate.User
- func UpdateTimeEQ(v time.Time) predicate.User
- func UpdateTimeGT(v time.Time) predicate.User
- func UpdateTimeGTE(v time.Time) predicate.User
- func UpdateTimeIn(vs ...time.Time) predicate.User
- func UpdateTimeLT(v time.Time) predicate.User
- func UpdateTimeLTE(v time.Time) predicate.User
- func UpdateTimeNEQ(v time.Time) predicate.User
- func UpdateTimeNotIn(vs ...time.Time) predicate.User
- func ValidColumn(column string) bool
- type OrderOption
- func ByAccessTokens(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAccessTokensCount(opts ...sql.OrderTermOption) OrderOption
- func ByCreateTime(opts ...sql.OrderTermOption) OrderOption
- func ByEmail(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLikeVideos(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByLikeVideosCount(opts ...sql.OrderTermOption) OrderOption
- func ByPassword(opts ...sql.OrderTermOption) OrderOption
- func ByRefreshTokens(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByRefreshTokensCount(opts ...sql.OrderTermOption) OrderOption
- func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreateTime holds the string denoting the create_time field in the database. FieldCreateTime = "create_time" // FieldUpdateTime holds the string denoting the update_time field in the database. FieldUpdateTime = "update_time" // FieldEmail holds the string denoting the email field in the database. FieldEmail = "email" // FieldPassword holds the string denoting the password field in the database. FieldPassword = "password" // EdgeAccessTokens holds the string denoting the access_tokens edge name in mutations. EdgeAccessTokens = "access_tokens" // EdgeLikeVideos holds the string denoting the like_videos edge name in mutations. EdgeLikeVideos = "like_videos" // EdgeRefreshTokens holds the string denoting the refresh_tokens edge name in mutations. EdgeRefreshTokens = "refresh_tokens" // Table holds the table name of the user in the database. Table = "users" // AccessTokensTable is the table that holds the access_tokens relation/edge. AccessTokensTable = "access_tokens" // AccessTokensInverseTable is the table name for the AccessToken entity. // It exists in this package in order to avoid circular dependency with the "accesstoken" package. AccessTokensInverseTable = "access_tokens" // AccessTokensColumn is the table column denoting the access_tokens relation/edge. AccessTokensColumn = "user_id" // LikeVideosTable is the table that holds the like_videos relation/edge. LikeVideosTable = "like_videos" // LikeVideosInverseTable is the table name for the LikeVideo entity. // It exists in this package in order to avoid circular dependency with the "likevideo" package. LikeVideosInverseTable = "like_videos" // LikeVideosColumn is the table column denoting the like_videos relation/edge. LikeVideosColumn = "user_id" // RefreshTokensTable is the table that holds the refresh_tokens relation/edge. RefreshTokensTable = "refresh_tokens" // RefreshTokensInverseTable is the table name for the RefreshToken entity. // It exists in this package in order to avoid circular dependency with the "refreshtoken" package. RefreshTokensInverseTable = "refresh_tokens" // RefreshTokensColumn is the table column denoting the refresh_tokens relation/edge. RefreshTokensColumn = "user_id" )
Variables ¶
var ( // DefaultCreateTime holds the default value on creation for the "create_time" field. DefaultCreateTime func() time.Time // DefaultUpdateTime holds the default value on creation for the "update_time" field. DefaultUpdateTime func() time.Time // UpdateDefaultUpdateTime holds the default value on update for the "update_time" field. UpdateDefaultUpdateTime func() time.Time // EmailValidator is a validator for the "email" field. It is called by the builders before save. EmailValidator func(string) error // PasswordValidator is a validator for the "password" field. It is called by the builders before save. PasswordValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreateTime, FieldUpdateTime, FieldEmail, FieldPassword, }
Columns holds all SQL columns for user fields.
Functions ¶
func CreateTime ¶
CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.
func CreateTimeEQ ¶
CreateTimeEQ applies the EQ predicate on the "create_time" field.
func CreateTimeGT ¶
CreateTimeGT applies the GT predicate on the "create_time" field.
func CreateTimeGTE ¶
CreateTimeGTE applies the GTE predicate on the "create_time" field.
func CreateTimeIn ¶
CreateTimeIn applies the In predicate on the "create_time" field.
func CreateTimeLT ¶
CreateTimeLT applies the LT predicate on the "create_time" field.
func CreateTimeLTE ¶
CreateTimeLTE applies the LTE predicate on the "create_time" field.
func CreateTimeNEQ ¶
CreateTimeNEQ applies the NEQ predicate on the "create_time" field.
func CreateTimeNotIn ¶
CreateTimeNotIn applies the NotIn predicate on the "create_time" field.
func Email ¶
Email applies equality check predicate on the "email" field. It's identical to EmailEQ.
func EmailContains ¶
EmailContains applies the Contains predicate on the "email" field.
func EmailContainsFold ¶
EmailContainsFold applies the ContainsFold predicate on the "email" field.
func EmailEqualFold ¶
EmailEqualFold applies the EqualFold predicate on the "email" field.
func EmailHasPrefix ¶
EmailHasPrefix applies the HasPrefix predicate on the "email" field.
func EmailHasSuffix ¶
EmailHasSuffix applies the HasSuffix predicate on the "email" field.
func EmailNotIn ¶
EmailNotIn applies the NotIn predicate on the "email" field.
func HasAccessTokens ¶
HasAccessTokens applies the HasEdge predicate on the "access_tokens" edge.
func HasAccessTokensWith ¶
func HasAccessTokensWith(preds ...predicate.AccessToken) predicate.User
HasAccessTokensWith applies the HasEdge predicate on the "access_tokens" edge with a given conditions (other predicates).
func HasLikeVideos ¶
HasLikeVideos applies the HasEdge predicate on the "like_videos" edge.
func HasLikeVideosWith ¶
HasLikeVideosWith applies the HasEdge predicate on the "like_videos" edge with a given conditions (other predicates).
func HasRefreshTokens ¶
HasRefreshTokens applies the HasEdge predicate on the "refresh_tokens" edge.
func HasRefreshTokensWith ¶
func HasRefreshTokensWith(preds ...predicate.RefreshToken) predicate.User
HasRefreshTokensWith applies the HasEdge predicate on the "refresh_tokens" edge with a given conditions (other predicates).
func Password ¶
Password applies equality check predicate on the "password" field. It's identical to PasswordEQ.
func PasswordContains ¶
PasswordContains applies the Contains predicate on the "password" field.
func PasswordContainsFold ¶
PasswordContainsFold applies the ContainsFold predicate on the "password" field.
func PasswordEQ ¶
PasswordEQ applies the EQ predicate on the "password" field.
func PasswordEqualFold ¶
PasswordEqualFold applies the EqualFold predicate on the "password" field.
func PasswordGT ¶
PasswordGT applies the GT predicate on the "password" field.
func PasswordGTE ¶
PasswordGTE applies the GTE predicate on the "password" field.
func PasswordHasPrefix ¶
PasswordHasPrefix applies the HasPrefix predicate on the "password" field.
func PasswordHasSuffix ¶
PasswordHasSuffix applies the HasSuffix predicate on the "password" field.
func PasswordIn ¶
PasswordIn applies the In predicate on the "password" field.
func PasswordLT ¶
PasswordLT applies the LT predicate on the "password" field.
func PasswordLTE ¶
PasswordLTE applies the LTE predicate on the "password" field.
func PasswordNEQ ¶
PasswordNEQ applies the NEQ predicate on the "password" field.
func PasswordNotIn ¶
PasswordNotIn applies the NotIn predicate on the "password" field.
func UpdateTime ¶
UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.
func UpdateTimeEQ ¶
UpdateTimeEQ applies the EQ predicate on the "update_time" field.
func UpdateTimeGT ¶
UpdateTimeGT applies the GT predicate on the "update_time" field.
func UpdateTimeGTE ¶
UpdateTimeGTE applies the GTE predicate on the "update_time" field.
func UpdateTimeIn ¶
UpdateTimeIn applies the In predicate on the "update_time" field.
func UpdateTimeLT ¶
UpdateTimeLT applies the LT predicate on the "update_time" field.
func UpdateTimeLTE ¶
UpdateTimeLTE applies the LTE predicate on the "update_time" field.
func UpdateTimeNEQ ¶
UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.
func UpdateTimeNotIn ¶
UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByAccessTokens ¶
func ByAccessTokens(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAccessTokens orders the results by access_tokens terms.
func ByAccessTokensCount ¶
func ByAccessTokensCount(opts ...sql.OrderTermOption) OrderOption
ByAccessTokensCount orders the results by access_tokens count.
func ByCreateTime ¶
func ByCreateTime(opts ...sql.OrderTermOption) OrderOption
ByCreateTime orders the results by the create_time field.
func ByEmail ¶
func ByEmail(opts ...sql.OrderTermOption) OrderOption
ByEmail orders the results by the email field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLikeVideos ¶
func ByLikeVideos(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByLikeVideos orders the results by like_videos terms.
func ByLikeVideosCount ¶
func ByLikeVideosCount(opts ...sql.OrderTermOption) OrderOption
ByLikeVideosCount orders the results by like_videos count.
func ByPassword ¶
func ByPassword(opts ...sql.OrderTermOption) OrderOption
ByPassword orders the results by the password field.
func ByRefreshTokens ¶
func ByRefreshTokens(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByRefreshTokens orders the results by refresh_tokens terms.
func ByRefreshTokensCount ¶
func ByRefreshTokensCount(opts ...sql.OrderTermOption) OrderOption
ByRefreshTokensCount orders the results by refresh_tokens count.
func ByUpdateTime ¶
func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption
ByUpdateTime orders the results by the update_time field.